#include <iostream>
#include <map>
#include <string>
#include <vector>
#include <algorithm>

// Structure to represent a sale
struct Sale {
    std::string product;
    double amount;
    std::string date;
};

// Function to print sales summary
void printSalesSummary(const std::multimap<std::string, Sale>& sales) {
    for (const auto& category : sales) {
        std::cout << "Category: " << category.first << std::endl;
        double total = 0.0;
        std::vector<double> amounts;
        for (auto it = sales.lower_bound(category.first); 
             it != sales.upper_bound(category.first); ++it) {
            total += it->second.amount;
            amounts.push_back(it->second.amount);
        }
        std::cout << "  Total Sales: $" << total << std::endl;
        if (!amounts.empty()) {
            std::cout << "  Average Sale: $" << total / amounts.size() << std::endl;
            std::cout << "  Highest Sale: $" << *std::max_element(amounts.begin(), amounts.end()) << std::endl;
        }
        std::cout << std::endl;
    }
}

int main() {
    std::multimap<std::string, Sale> salesData;

    // Inserting sales data
    salesData.insert({"Electronics", {"Laptop", 1200.00, "2023-01-15"}});
    salesData.insert({"Clothing", {"T-Shirt", 25.99, "2023-01-16"}});
    salesData.insert({"Electronics", {"Smartphone", 800.00, "2023-01-17"}});
    salesData.insert({"Clothing", {"Jeans", 59.99, "2023-01-18"}});
    salesData.insert({"Electronics", {"Headphones", 150.00, "2023-01-19"}});
    salesData.insert({"Clothing", {"Dress", 89.99, "2023-01-20"}});

    // Print sales summary
    printSalesSummary(salesData);

    return 0;
}
